==> acs-0.28.tar.gz: acs-0.28/modelgen/ap_get.cc <==
/*$Id: ap_get.cc,v 18.9 2000/08/16 08:11:43 al Exp $ -*- C++ -*-
 * get value for matching keyword
 */
#include "ap.h"
/*--------------------------------------------------------------------------*/
bool get(CS& cmd, const std::string& key, bool* val, AP_MOD m)
{
  assert(m==mNONE || m==mINVERT);
  std::string false_key("NO" + key);

  {if (cmd.pmatch(key)){
    /**/ set(cmd, "1",     val, true)
      || set(cmd, "0",     val, false)
      || set(cmd, "True",  val, true)
      || set(cmd, "False", val, false)
      || set(cmd, "Yes",   val, true)
      || set(cmd, "No",    val, false)
      || set(cmd, "#True", val, true)
      || set(cmd, "#False",val, false)
      || (*val = true);
    cmd.reset(cmd.cursor()); // cheat: set "ok" flag to true
    if (m==mINVERT){
      untested();
      *val = !*val;
    }
    return true;
  }else if (cmd.pmatch(false_key)){
    *val = (m==mINVERT);
    return true;
  }else{
    return false;
  }}
}
/*--------------------------------------------------------------------------*/
bool get(CS& cmd, const std::string& key, int* val, AP_MOD mod, int scale)
{
  {if (cmd.pmatch(key)){
    switch(mod){
      case mNONE:		  *val = int(cmd.ctof());	break;
      case mSCALE:    untested(); *val = int(cmd.ctof())*scale;	break;
      case mOFFSET:   untested(); *val = int(cmd.ctof())+scale;	break;
      case mINVERT:   untested(); *val = 1 / int(cmd.ctof());	break;
      case mPOSITIVE: untested(); *val = abs(int(cmd.ctof()));	break;
      case mOCTAL:		  *val = cmd.ctoo();		break;
      case mHEX:      untested(); *val = cmd.ctox();		break;
    }
    return true;
  }else{
    return false;
  }}
}
/*--------------------------------------------------------------------------*/
bool get(CS& cmd, const std::string& key, double* val, AP_MOD mod, double scale)
{
  {if (cmd.pmatch(key)){
    cmd >> *val;
    switch(mod){
    case mNONE: 	/*nothing*/		break;
    case mSCALE:	*val *= scale;		break;
    case mOFFSET:	*val += scale;		break;
    case mINVERT: untested(); *val = 1 / *val;	break;
    case mPOSITIVE:	*val = abs(*val);	break;
    case mOCTAL:	unreachable();		break;
    case mHEX:  	unreachable();		break;
    }
    return true;
  }else{
    return false;
  }}
}    
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/

==> acs-0.29.tar.gz: acs-0.29/modelgen/ap_get.cc <==
/*$Id: ap_get.cc,v 19.14 2001/04/06 00:55:33 al Exp $ -*- C++ -*-
 * get value for matching keyword
 */
#include "ap.h"
/*--------------------------------------------------------------------------*/
bool get(CS& cmd, const std::string& key, bool* val, AP_MOD m)
{
  assert(m==mNONE || m==mINVERT);
  std::string false_key("NO" + key);

  {if (cmd.dmatch(key)){
    /**/ set(cmd, "1",     val, true)
      || set(cmd, "0",     val, false)
      || set(cmd, "True",  val, true)
      || set(cmd, "False", val, false)
      || set(cmd, "Yes",   val, true)
      || set(cmd, "No",    val, false)
      || set(cmd, "#True", val, true)
      || set(cmd, "#False",val, false)
      || (*val = true);
    cmd.reset(cmd.cursor()); // cheat: set "ok" flag to true
    if (m==mINVERT){
      untested();
      *val = !*val;
    }
    return true;
  }else if (cmd.dmatch(false_key)){
    *val = (m==mINVERT);
    return true;
  }else{
    return false;
  }}
}
/*--------------------------------------------------------------------------*/
bool get(CS& cmd, const std::string& key, int* val, AP_MOD mod, int scale)
{
  {if (cmd.dmatch(key)){
    switch(mod){
      case mNONE:		  *val = int(cmd.ctof());	break;
      case mSCALE:    untested(); *val = int(cmd.ctof())*scale;	break;
      case mOFFSET:   untested(); *val = int(cmd.ctof())+scale;	break;
      case mINVERT:   untested(); *val = 1 / int(cmd.ctof());	break;
      case mPOSITIVE: untested(); *val = abs(int(cmd.ctof()));	break;
      case mOCTAL:		  *val = cmd.ctoo();		break;
      case mHEX:      untested(); *val = cmd.ctox();		break;
    }
    return true;
  }else{
    return false;
  }}
}
/*--------------------------------------------------------------------------*/
bool get(CS& cmd, const std::string& key, double* val, AP_MOD mod, double scale)
{
  {if (cmd.dmatch(key)){
    cmd >> *val;
    switch(mod){
    case mNONE: 	/*nothing*/		break;
    case mSCALE:	*val *= scale;		break;
    case mOFFSET:	*val += scale;		break;
    case mINVERT: untested(); *val = 1 / *val;	break;
    case mPOSITIVE:	*val = abs(*val);	break;
    case mOCTAL:	unreachable();		break;
    case mHEX:  	unreachable();		break;
    }
    return true;
  }else{
    return false;
  }}
}    
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
